@@ -16,21 +16,20 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-gboolean show_version (gchar*, gchar*, gpointer, GError**);
-gboolean set_font (gchar*, gchar*, gpointer, GError**);
-gboolean set_cmd (gchar*, gchar*, gpointer, GError**);
-gboolean set_scroll (gchar*, gchar*, gpointer, GError**);
-gboolean set_color (gchar*, gchar*, gpointer, GError**);
-gboolean set_cfg (gchar*, gchar*, gpointer, GError**);
+gboolean show_version (gchar *, gchar *, gpointer, GError **);
+gboolean set_font (gchar *, gchar *, gpointer, GError **);
+gboolean set_cmd (gchar *, gchar *, gpointer, GError **);
+gboolean set_scroll (gchar *, gchar *, gpointer, GError **);
+gboolean set_color (gchar *, gchar *, gpointer, GError **);
+gboolean set_cfg (gchar *, gchar *, gpointer, GError **);
 
 void add_env (gpointer, gpointer, gpointer);
 
-void child_stop (GtkWidget*, gpointer);
-void window_set_title (GtkWidget*, gpointer);
+void window_set_title (GtkWidget *, gpointer);
 
-void drop_data (GtkWidget*, GdkDragContext*, gint, gint, 
-		GtkSelectionData*, guint, guint, gpointer);
+void drop_data (GtkWidget *, GdkDragContext *, gint, gint,
+                GtkSelectionData *, guint, guint, gpointer);
 
 #ifdef USE_MENU
-int button_pressed (GtkWidget*, GdkEventButton*, gpointer);
+gboolean popup_menu (GtkWidget *, GdkEventButton *, gpointer);
 #endif
